k8s package
===========

.. automodule:: k8s
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    k8s.models

Submodules
----------

.. toctree::

   k8s.base
   k8s.client
   k8s.config
   k8s.fields
   k8s.watcher

